import { Observable } from '@nativescript/core';
import { CanvasRenderingContext2D } from './contexts/CanvasRenderingContext2D';
import { ImageBitmapRenderingContext } from './contexts/ImageBitmapRenderingContext';
class NSHTMLCanvasElement extends Observable {
    constructor(canvasView, canvasContext) {
        super();
        this._canvasViewRef = new WeakRef(canvasView);
        this._contextRef = new WeakRef(canvasContext);
    }
    getContext(contextId) {
        let cl;
        switch (contextId) {
            case '2d':
                cl = CanvasRenderingContext2D;
                break;
            case 'bitmaprenderer':
                cl = ImageBitmapRenderingContext;
                break;
            default:
                cl = null;
                break;
        }
        if (cl == null) {
            return null;
        }
        if (this._context != null && this._context instanceof cl) {
            return this._context;
        }
        this._context = new cl(this);
        return this._context;
    }
    get view() {
        return this._canvasViewRef.deref();
    }
    get nativeContext() {
        return this._contextRef.deref();
    }
    get width() {
        const context = this.nativeContext;
        return context != null ? context.getWidth() : 0;
    }
    set width(val) {
        const view = this.view;
        if (view) {
            view.width = val;
        }
    }
    get height() {
        const context = this.nativeContext;
        return context != null ? context.getHeight() : 0;
    }
    set height(val) {
        const view = this.view;
        if (view) {
            view.height = val;
        }
    }
}
export { NSHTMLCanvasElement as HTMLCanvasElement };
//# sourceMappingURL=HTMLCanvasElement.js.map